#!/bin/sh
#
# source: ftp.openbsd.org/pub/OpenBSD/OpenSSH/portable/openssh-5.0p1.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

VERSION=5.1p1
ARCH=${ARCH:-i486}
BUILD=54.2

CWD=`pwd`
PKG=/tmp/package-openssh

# Clean target location:
rm -rf $PKG
mkdir -p $PKG

# Prepare the framework and extract the package:
cd /tmp
rm -rf $PKG openssh-$VERSION
tar xvzf $CWD/openssh-$VERSION.tar.gz
cd openssh-$VERSION
chown -R root:root .

# Compile package:
CFLAGS="-O2 -march=i486 -mtune=i686" \
./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --sysconfdir=/etc/ssh \
  --with-pam \
  --with-md5-passwords \
  --with-tcp-wrappers \
  --with-default-path=/usr/local/sbin:/usr/sbin:/sbin:/usr/local/bin:/usr/bin:/bin \
  --with-ipv4-default \
  --with-privsep-path=/var/empty \
  --with-privsep-user=sshd

make -j2
make install DESTDIR=$PKG

( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress and if needed symlink the man pages:
if [ -d $PKG/usr/man ]; then
  ( cd $PKG/usr/man
    for manpagedir in $(find . -type d -name "man*") ; do
      ( cd $manpagedir
        for eachpage in $( find . -type l -maxdepth 1) ; do
          ln -s $( readlink $eachpage ).gz $eachpage.gz
          rm $eachpage
        done
        gzip -9 *.?
      )
    done
  )
fi

# Install pam.sshd
mkdir -p $PKG/etc/pam.d
cat $CWD/sshd.pam > $PKG/etc/pam.d/sshd.new
chmod 644 $PKG/etc/pam.d/sshd

# Install directory used with PrivilegeSeparation option:
mkdir -p $PKG/var/empty
chmod 755 $PKG/var/empty

# Install docs:
mkdir -p $PKG/usr/doc/openssh-$VERSION
cp -a \
  CREDITS ChangeLog INSTALL LICENCE OVERVIEW README README.privsep README.smartcard TODO WARNING.RNG \
  $PKG/usr/doc/openssh-$VERSION
chmod 644 $PKG/usr/doc/openssh-$VERSION/*

# Install also 'ssh-copy-id' and its manpage from contrib:
( cd contrib
  cp -a ssh-copy-id $PKG/usr/bin/ssh-copy-id
  chmod 755 $PKG/usr/bin/ssh-copy-id
  cat ssh-copy-id.1 | gzip -9c > $PKG/usr/man/man1/ssh-copy-id.1.gz
)

# Fix some ownerships per FSSTND:
chown -R root.bin $PKG/usr/bin $PKG/usr/sbin

( cd $PKG

  # Ditch the new host keys, since these have to be uniquely prepared on each machine:
  rm -f etc/ssh/ssh_host_dsa_key
  rm -f etc/ssh/ssh_host_dsa_key.pub
  rm -f etc/ssh/ssh_host_rsa_key
  rm -f etc/ssh/ssh_host_rsa_key.pub
  rm -f etc/ssh/ssh_host_key
  rm -f etc/ssh/ssh_host_key.pub

  # Set up the config script installation:
  mv etc/ssh/ssh_config etc/ssh/ssh_config.new
  mv etc/ssh/sshd_config etc/ssh/sshd_config.new

  # Add the init script:
  mkdir -p etc/rc.d
  cat $CWD/rc.sshd > etc/rc.d/rc.sshd
  chmod 644 etc/rc.d/rc.sshd

  # Copy runtime installation files:
  mkdir -p install
  zcat $CWD/doinst.sh.gz > install/doinst.sh
)
#-----------------Make the slack-desc files

cat << EODESC > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|' on
# the right side marks the last column you can put a character in.  You must make
# exactly 11 lines for the formatting to be correct.  It's also customary to
# leave one space after the ':'.

       |-----handy-ruler--------------------------------------------------------|
openssh: openssh (Secure Shell daemon and clients)
openssh:
openssh: ssh (Secure Shell) is a program for logging into a remote machine and
openssh: for executing commands on a remote machine.  It is intended to replace
openssh: rlogin and rsh, and provide secure encrypted communications between
openssh: two untrusted hosts over an insecure network.  sshd (SSH Daemon) is
openssh: the daemon program for ssh.  OpenSSH is based on the last free version
openssh: of Tatu Ylonen's SSH, further enhanced and cleaned up by Aaron
openssh: Campbell, Bob Beck, Markus Friedl, Niels Provos, Theo de Raadt, and
openssh: Dug Song.  It has a homepage at http://www.openssh.com/
openssh:
EODESC

mkdir -p $PKG/usr/src/openssh-$VERSION
cp $CWD/build-openssh.sh $PKG/usr/src/openssh-$VERSION
cp $CWD/doinst.sh.gz $PKG/usr/src/openssh-$VERSION
cp $CWD/rc.sshd $PKG/usr/src/openssh-$VERSION

# Create the package itself:
cd $PKG
makepkg -l y -c n $CWD/openssh-$VERSION-$ARCH-$BUILD.tgz
